LIVE_PLOTS_ENABLE = False

LIVE_PLOTS_ATTRIBUTES = ['lo_max_freq', 'charge_time', 'total_dco', 'temperature',
                         'gpio4_sense']  # 'gpio4_sense' charge_time
LIVE_PLOTS_ANIMATE = False
LIVE_PLOTS_DEQUE_LENGTH = 1000
LIVE_PLOTS_HISTORY = 1800 # history shown in graph [seconds]
